@@ -29,7 +29,7 @@ def init(client: "Client"):
 
         # if command is in commands list
         if cmd in client.commands:
-            logging.info(f"la commande : {cmd}, by {message.author}")
+            logging.info(f"command: {cmd}, by {message.author} in {message.guild} on {message.channel} channel")
             func = client.commands[cmd]
             # Call the appropriate for the command wanted and pass the discord.Message in parameters
-            asyncio.run_coroutine_threadsafe(func(message), asyncio.get_event_loop())
+            asyncio.run_coroutine_threadsafe(func(message), client.loop)
